# eric7.Preferences.ConfigurationPages.EditorDocViewerPage

Module implementing the Editor Documentation Viewer configuration page.

### Global Attributes

None

### Classes

EditorDocViewerPage | Class implementing the Editor Documentation Viewer configuration page.

### Functions

create | Module function to create the configuration page.

## EditorDocViewerPage

Class implementing the Editor Documentation Viewer configuration page.

### Derived from

ConfigurationPageBase, Ui_EditorDocViewerPage

### Class Attributes

None

### Class Methods

None

### Methods

EditorDocViewerPage | Constructor
save | Public slot to save the Editor Typing configuration.

### Static Methods

None

#### EditorDocViewerPage (Constructor)

EditorDocViewerPage()

Constructor

#### EditorDocViewerPage.save

save()

Public slot to save the Editor Typing configuration.

Up

## create

create(_dlg)

Module function to create the configuration page.

_dlg (ConfigurationDialog)
  reference to the configuration dialog (unused)

Return:
  reference to the instantiated page

Return Type:
  ConfigurationPageBase

Up